@@ -14,7 +14,11 @@ def get_permissions_from_request(request: WebRequest) -> list:
         if (perm := request.POST.get(f"permission_{group}")) in items["options"]
     ]
 
-    scopes.extend(f"{group}:read" for group, items in SCOPE_DESCRIPTIONS.items() if request.POST.get(f"permission_{group}") == "write")
+    scopes.extend(
+        f"{group}:read"
+        for group, items in SCOPE_DESCRIPTIONS.items()
+        if request.POST.get(f"permission_{group}") == "write" and f"{group}:read" in SCOPES
+    )
 
     return scopes
 
